from flashcards.models import Flashcard, UserFlashcardQuiz
from rest_framework.exceptions import PermissionDenied
from rest_framework.pagination import PageNumberPagination
from rest_framework.permissions import BasePermission

mock_no_params = lambda x: None


class StandardResultsSetPagination(PageNumberPagination):
    page_size = 40
    page_size_query_param = 'page_size'
    max_page_size = 1000


class UserDetailPermissions(BasePermission):
    """
    Permissions for the user detail view. Anonymous users may only POST.
    """

    def has_object_permission(self, request, view, obj):
        if request.method == 'POST':
            return True
        return request.user.is_authenticated()


class IsEnrolledInAssociatedSection(BasePermission):
    def has_object_permission(self, request, view, obj):
        if obj is None:
            return True
        assert type(obj) is Flashcard
        return request.user.is_in_section(obj.section)


class IsFlashcardReviewer(BasePermission):
    def has_object_permission(self, request, view, obj):
        if obj is None:
            return True
        assert type(obj) is UserFlashcardQuiz
        return request.user == obj.user_flashcard.user


class IsAuthenticatedAndConfirmed(BasePermission):
    """
    Allows access only to authenticated users who have verified their email address, with a 24 hour grace period
    """

    def has_permission(self, request, view):
        if not request.user: return False
        if not request.user.is_authenticated(): return False
        if request.user.locked: raise PermissionDenied('Please verify your email before continuing')
        return True
