# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.contrib.auth.models
import django.utils.timezone
from django.conf import settings
import django.core.validators
import simple_email_confirmation.models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '__latest__'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(null=True, verbose_name='last login', blank=True)),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(error_messages={'unique': 'A user with that username already exists.'}, max_length=30, validators=[django.core.validators.RegexValidator('^[\\w.@+-]+$', 'Enter a valid username. This value may contain only letters, numbers and @/./+/-/_ characters.', 'invalid')], help_text='Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', unique=True, verbose_name='username')),
                ('first_name', models.CharField(max_length=30, verbose_name='first name', blank=True)),
                ('last_name', models.CharField(max_length=30, verbose_name='last name', blank=True)),
                ('email', models.EmailField(unique=True, max_length=254, verbose_name='email address', blank=True)),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('groups', models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Group', blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', verbose_name='groups')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
            bases=(models.Model, simple_email_confirmation.models.SimpleEmailConfirmationUserMixin),
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='Flashcard',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('text', models.CharField(help_text=b'The text on the card', max_length=255)),
                ('pushed', models.DateTimeField(help_text=b'When the card was first pushed', auto_now_add=True)),
                ('material_date', models.DateTimeField(help_text=b'The date with which the card is associated')),
                ('is_hidden', models.BooleanField(default=False)),
                ('hide_reason', models.CharField(help_text=b'Reason for hiding this card', max_length=255, blank=True)),
                ('author', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-pushed'],
            },
        ),
        migrations.CreateModel(
            name='FlashcardMask',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ranges', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='FlashcardReport',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('reason', models.CharField(max_length=255)),
                ('flashcard', models.ForeignKey(to='flashcards.Flashcard')),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='LecturePeriod',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('week_day', models.IntegerField(help_text=b'0-indexed day of week, starting at Monday')),
                ('start_time', models.TimeField()),
                ('end_time', models.TimeField()),
            ],
        ),
        migrations.CreateModel(
            name='Section',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('department', models.CharField(max_length=50)),
                ('course_num', models.CharField(max_length=6)),
                ('course_title', models.CharField(max_length=50)),
                ('instructor', models.CharField(max_length=50)),
                ('quarter', models.CharField(max_length=4)),
                ('whitelist', models.ManyToManyField(related_name='whitelisted_sections', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-quarter'],
            },
        ),
        migrations.CreateModel(
            name='UserFlashcard',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('pulled', models.DateTimeField(help_text=b'When the user pulled the card', null=True, blank=True)),
                ('unpulled', models.DateTimeField(help_text=b'When the user unpulled this card', null=True, blank=True)),
                ('flashcard', models.ForeignKey(to='flashcards.Flashcard')),
                ('mask', models.ForeignKey(help_text=b"A mask which overrides the card's mask", to='flashcards.FlashcardMask')),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-pulled'],
            },
        ),
        migrations.CreateModel(
            name='UserFlashcardReview',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('when', models.DateTimeField()),
                ('blanked_word', models.CharField(help_text=b'The character range which was blanked', max_length=8, blank=True)),
                ('response', models.CharField(help_text=b"The user's response", max_length=255, null=True, blank=True)),
                ('correct', models.NullBooleanField(help_text=b"The user's self-evaluation of their response")),
                ('user_flashcard', models.ForeignKey(to='flashcards.UserFlashcard')),
            ],
        ),
        migrations.CreateModel(
            name='WhitelistedAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('email', models.EmailField(max_length=254)),
                ('section', models.ForeignKey(to='flashcards.Section')),
            ],
        ),
        migrations.AddField(
            model_name='lectureperiod',
            name='section',
            field=models.ForeignKey(to='flashcards.Section'),
        ),
        migrations.AddField(
            model_name='flashcard',
            name='mask',
            field=models.ForeignKey(blank=True, to='flashcards.FlashcardMask', help_text=b'The default mask for this card', null=True),
        ),
        migrations.AddField(
            model_name='flashcard',
            name='previous',
            field=models.ForeignKey(blank=True, to='flashcards.Flashcard', help_text=b'The previous version of this card, if one exists', null=True),
        ),
        migrations.AddField(
            model_name='flashcard',
            name='section',
            field=models.ForeignKey(help_text=b'The section with which the card is associated', to='flashcards.Section'),
        ),
        migrations.AddField(
            model_name='user',
            name='sections',
            field=models.ManyToManyField(to='flashcards.Section'),
        ),
        migrations.AddField(
            model_name='user',
            name='user_permissions',
            field=models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Permission', blank=True, help_text='Specific permissions for this user.', verbose_name='user permissions'),
        ),
        migrations.AlterUniqueTogether(
            name='userflashcard',
            unique_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterIndexTogether(
            name='userflashcard',
            index_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterUniqueTogether(
            name='section',
            unique_together=set([('department', 'course_num', 'quarter', 'instructor')]),
        ),
        migrations.AlterUniqueTogether(
            name='lectureperiod',
            unique_together=set([('section', 'start_time', 'week_day')]),
        ),
        migrations.AlterUniqueTogether(
            name='flashcardreport',
            unique_together=set([('user', 'flashcard')]),
        ),
    ]
