# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.contrib.auth.models
import django.utils.timezone
from django.conf import settings
import django.core.validators
import simple_email_confirmation.models
import flashcards.models
import flashcards.fields


class Migration(migrations.Migration):

    replaces = [(b'flashcards', '0001_initial'), (b'flashcards', '0002_auto_20150504_1327'), (b'flashcards', '0003_auto_20150504_1600'), (b'flashcards', '0004_auto_20150506_1443'), (b'flashcards', '0005_auto_20150510_1458'), (b'flashcards', '0006_auto_20150512_0042'), (b'flashcards', '0007_userflashcard_mask'), (b'flashcards', '0008_section_department_abbreviation'), (b'flashcards', '0009_auto_20150512_0318'), (b'flashcards', '0010_auto_20150513_1546'), (b'flashcards', '0011_auto_20150514_0207'), (b'flashcards', '0012_auto_20150516_0313'), (b'flashcards', '0013_auto_20150517_0402'), (b'flashcards', '0013_auto_20150516_2356'), (b'flashcards', '0014_merge'), (b'flashcards', '0015_auto_20150518_0017')]

    dependencies = [
        ('auth', '__latest__'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(null=True, verbose_name='last login', blank=True)),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(error_messages={'unique': 'A user with that username already exists.'}, max_length=30, validators=[django.core.validators.RegexValidator('^[\\w.@+-]+$', 'Enter a valid username. This value may contain only letters, numbers and @/./+/-/_ characters.', 'invalid')], help_text='Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', unique=True, verbose_name='username')),
                ('first_name', models.CharField(max_length=30, verbose_name='first name', blank=True)),
                ('last_name', models.CharField(max_length=30, verbose_name='last name', blank=True)),
                ('email', models.EmailField(unique=True, max_length=254, verbose_name='email address', blank=True)),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('groups', models.ManyToManyField(related_query_name='user', related_name='user_set', to=b'auth.Group', blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', verbose_name='groups')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
            bases=(models.Model, simple_email_confirmation.models.SimpleEmailConfirmationUserMixin),
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='Flashcard',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('text', models.CharField(help_text=b'The text on the card', max_length=255)),
                ('pushed', models.DateTimeField(help_text=b'When the card was first pushed', auto_now_add=True)),
                ('material_date', models.DateTimeField(help_text=b'The date with which the card is associated')),
                ('is_hidden', models.BooleanField(default=False)),
                ('hide_reason', models.CharField(help_text=b'Reason for hiding this card', max_length=255, blank=True)),
                ('author', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-pushed'],
            },
        ),
        migrations.CreateModel(
            name='FlashcardMask',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ranges', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='FlashcardReport',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('reason', models.CharField(max_length=255)),
                ('flashcard', models.ForeignKey(to='flashcards.Flashcard')),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='LecturePeriod',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('week_day', models.IntegerField(help_text=b'0-indexed day of week, starting at Monday')),
                ('start_time', models.TimeField()),
                ('end_time', models.TimeField()),
            ],
        ),
        migrations.CreateModel(
            name='Section',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('department', models.CharField(max_length=50)),
                ('course_num', models.CharField(max_length=6)),
                ('course_title', models.CharField(max_length=50)),
                ('instructor', models.CharField(max_length=50)),
                ('quarter', models.CharField(max_length=4)),
                ('whitelist', models.ManyToManyField(related_name='whitelisted_sections', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-quarter'],
            },
        ),
        migrations.CreateModel(
            name='UserFlashcard',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('pulled', models.DateTimeField(help_text=b'When the user pulled the card', null=True, blank=True)),
                ('unpulled', models.DateTimeField(help_text=b'When the user unpulled this card', null=True, blank=True)),
                ('flashcard', models.ForeignKey(to='flashcards.Flashcard')),
                ('mask', models.ForeignKey(help_text=b"A mask which overrides the card's mask", to='flashcards.FlashcardMask')),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-pulled'],
            },
        ),
        migrations.CreateModel(
            name='WhitelistedAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('email', models.EmailField(max_length=254)),
                ('section', models.ForeignKey(related_name='whitelist', to='flashcards.Section')),
            ],
        ),
        migrations.AddField(
            model_name='lectureperiod',
            name='section',
            field=models.ForeignKey(to='flashcards.Section'),
        ),
        migrations.AddField(
            model_name='flashcard',
            name='previous',
            field=models.ForeignKey(blank=True, to='flashcards.Flashcard', help_text=b'The previous version of this card, if one exists', null=True),
        ),
        migrations.AddField(
            model_name='flashcard',
            name='section',
            field=models.ForeignKey(help_text=b'The section with which the card is associated', to='flashcards.Section'),
        ),
        migrations.AddField(
            model_name='user',
            name='sections',
            field=models.ManyToManyField(to=b'flashcards.Section'),
        ),
        migrations.AddField(
            model_name='user',
            name='user_permissions',
            field=models.ManyToManyField(related_query_name='user', related_name='user_set', to=b'auth.Permission', blank=True, help_text='Specific permissions for this user.', verbose_name='user permissions'),
        ),
        migrations.AlterUniqueTogether(
            name='userflashcard',
            unique_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterIndexTogether(
            name='userflashcard',
            index_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterUniqueTogether(
            name='section',
            unique_together=set([('department', 'course_num', 'quarter', 'instructor')]),
        ),
        migrations.AlterUniqueTogether(
            name='lectureperiod',
            unique_together=set([('section', 'start_time', 'week_day')]),
        ),
        migrations.AlterUniqueTogether(
            name='flashcardreport',
            unique_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterModelOptions(
            name='section',
            options={},
        ),
        migrations.AlterModelManagers(
            name='user',
            managers=[
                ('objects', flashcards.models.EmailOnlyUserManager()),
            ],
        ),
        migrations.AlterField(
            model_name='flashcardreport',
            name='reason',
            field=models.CharField(max_length=255, blank=True),
        ),
        migrations.AlterField(
            model_name='lectureperiod',
            name='week_day',
            field=models.IntegerField(help_text=b'1-indexed day of week, starting at Sunday'),
        ),
        migrations.AlterField(
            model_name='user',
            name='sections',
            field=models.ManyToManyField(help_text=b'The sections which the user is enrolled in', to=b'flashcards.Section'),
        ),
        migrations.AlterField(
            model_name='user',
            name='username',
            field=models.CharField(help_text='Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=30, error_messages={'unique': 'A user with that username already exists.'}, verbose_name='username', validators=[django.core.validators.RegexValidator('^[\\w.@+-]+$', 'Enter a valid username. This value may contain only letters, numbers and @/./+/-/_ characters.', 'invalid')]),
        ),
        migrations.AlterField(
            model_name='section',
            name='instructor',
            field=models.CharField(max_length=100),
        ),
        migrations.AlterField(
            model_name='userflashcard',
            name='mask',
            field=models.ForeignKey(blank=True, to='flashcards.FlashcardMask', help_text=b"A mask which overrides the card's mask", null=True),
        ),
        migrations.CreateModel(
            name='UserFlashcardQuiz',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('when', models.DateTimeField(auto_now=True)),
                ('blanked_word', models.CharField(help_text=b'The character range which was blanked', max_length=8, blank=True)),
                ('response', models.CharField(help_text=b"The user's response", max_length=255, null=True, blank=True)),
                ('correct', models.NullBooleanField(help_text=b"The user's self-evaluation of their response")),
                ('user_flashcard', models.ForeignKey(to='flashcards.UserFlashcard')),
            ],
        ),
        migrations.AlterModelOptions(
            name='section',
            options={'ordering': ['-course_title']},
        ),
        migrations.AlterUniqueTogether(
            name='section',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='section',
            name='whitelist',
        ),
        migrations.RemoveField(
            model_name='userflashcard',
            name='mask',
        ),
        migrations.DeleteModel(
            name='FlashcardMask',
        ),
        migrations.AddField(
            model_name='flashcard',
            name='mask',
            field=flashcards.fields.MaskField(blank_sep=b',', range_sep=b'-', max_length=255, blank=True, help_text=b'The mask on the card', null=True),
        ),
        migrations.AddField(
            model_name='userflashcard',
            name='mask',
            field=flashcards.fields.MaskField(default=None, blank_sep=b',', range_sep=b'-', max_length=255, blank=True, help_text=b'The user-specific mask on the card', null=True),
        ),
        migrations.AddField(
            model_name='section',
            name='department_abbreviation',
            field=models.CharField(max_length=10, db_index=True),
        ),
        migrations.AlterField(
            model_name='section',
            name='course_num',
            field=models.CharField(max_length=6, db_index=True),
        ),
        migrations.AlterField(
            model_name='section',
            name='course_title',
            field=models.CharField(max_length=50, db_index=True),
        ),
        migrations.AlterField(
            model_name='section',
            name='department',
            field=models.CharField(max_length=50, db_index=True),
        ),
        migrations.AlterField(
            model_name='section',
            name='instructor',
            field=models.CharField(max_length=100, db_index=True),
        ),
        migrations.AlterField(
            model_name='section',
            name='quarter',
            field=models.CharField(max_length=4, db_index=True),
        ),
        migrations.AlterField(
            model_name='flashcard',
            name='material_date',
            field=models.DateTimeField(default=django.utils.timezone.now, help_text=b'The date with which the card is associated'),
        ),
        migrations.AlterModelOptions(
            name='lectureperiod',
            options={'ordering': ['section', 'week_day']},
        ),
        migrations.AlterField(
            model_name='userflashcard',
            name='pulled',
            field=models.DateTimeField(default=None, help_text=b'When the user pulled the card', null=True, blank=True),
        ),
        migrations.RemoveField(
            model_name='userflashcard',
            name='unpulled',
        ),
        migrations.CreateModel(
            name='FlashcardHide',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('reason', models.CharField(max_length=255, null=True, blank=True)),
                ('hidden', models.DateTimeField(auto_now_add=True)),
                ('flashcard', models.ForeignKey(to='flashcards.Flashcard')),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='flashcardreport',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='flashcardreport',
            name='flashcard',
        ),
        migrations.RemoveField(
            model_name='flashcardreport',
            name='user',
        ),
        migrations.DeleteModel(
            name='FlashcardReport',
        ),
        migrations.AlterUniqueTogether(
            name='flashcardhide',
            unique_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterIndexTogether(
            name='flashcardhide',
            index_together=set([('user', 'flashcard')]),
        ),
        migrations.AlterField(
            model_name='flashcard',
            name='hide_reason',
            field=models.CharField(default=None, help_text=b'Reason for hiding this card', max_length=255, blank=True),
        ),
        migrations.AlterField(
            model_name='flashcard',
            name='previous',
            field=models.ForeignKey(default=None, blank=True, to='flashcards.Flashcard', help_text=b'The previous version of this card, if one exists', null=True),
        ),
        migrations.AlterField(
            model_name='flashcard',
            name='hide_reason',
            field=models.CharField(default=None, max_length=255, null=True, help_text=b'Reason for hiding this card', blank=True),
        ),
        migrations.AlterField(
            model_name='flashcard',
            name='previous',
            field=models.ForeignKey(default=None, blank=True, to='flashcards.Flashcard', help_text=b'The previous version of this card, if one exists', null=True),
        ),
        migrations.AlterField(
            model_name='flashcard',
            name='hide_reason',
            field=models.CharField(default=b'', max_length=255, null=True, help_text=b'Reason for hiding this card', blank=True),
        ),
    ]
