# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from math import log1p, exp

from django.db import models, migrations
from django.utils.timezone import make_aware


def update_scores(apps, schema_editor):
    Flashcard = apps.get_model("flashcards", "Flashcard")
    for card in Flashcard.objects.all():
        def seconds_since_epoch(dt):
            from datetime import datetime

            epoch = make_aware(datetime.utcfromtimestamp(0))
            delta = dt - epoch
            return delta.total_seconds()

        z = 0
        rate = 1.0 / 3600
        for vote in card.userflashcard_set.iterator():
            t = seconds_since_epoch(vote.pulled)
            u = max(z, rate * t)
            v = min(z, rate * t)
            z = u + log1p(exp(v - u))
        card.score = z
        card.save()


class Migration(migrations.Migration):
    dependencies = [
        ('flashcards', '0017_auto_20150601_2001'),
    ]

    operations = [
        migrations.AddField(
            model_name='flashcard',
            name='score',
            field=models.FloatField(default=0),
            preserve_default=False,
        ),
        migrations.RunPython(update_scores),
    ]
