from collections import Iterable
from random import sample


class FlashcardMask(set):
    def __init__(self, iterable, *args, **kwargs):
        if iterable is None or iterable == '':
            iterable = []
        self._iterable_check(iterable)
        iterable = map(tuple, iterable)
        super(FlashcardMask, self).__init__(iterable, *args, **kwargs)
        self._interval_check()
        self._overlap_check()

    def max_offset(self):
        return self._end

    def get_random_blank(self):
        if self.max_offset() > 0:
            return list(sample(self, 1)[0])
        return []

    def _iterable_check(self, iterable):
        if not isinstance(iterable, Iterable) or not all([isinstance(i, Iterable) for i in iterable]):
            raise TypeError("Interval not a valid iterable")

    def _interval_check(self):
        if not all([len(i) == 2 for i in self]):
            raise TypeError("Intervals must have exactly 2 elements, begin and end")

    def _overlap_check(self):
        p_beg, p_end = -1, -1
        for interval in sorted(self):
            beg, end = map(int, interval)
            if not (0 <= beg <= 255) or not (0 <= end <= 255) or not (beg <= end) or not (beg > p_end):
                raise OverlapIntervalException((beg, end), "Invalid interval offsets in the mask")
            p_beg, p_end = beg, end
        self._end = p_end


class OverlapIntervalException(Exception):
    def __init__(self, interval, message):
        self.interval = interval
        self.message = message

    def __str__(self):
        return repr(self.message) + ': ' + repr(self.interval)
