from django.conf.urls import include, url
from django.contrib import admin
from flashcards.views import SectionViewSet, UserDetail, FlashcardViewSet, UserSectionListView, request_password_reset, \
    reset_password, logout, login, register, UserFlashcardQuizViewSet, \
    resend_confirmation_email, verify_email, subscribe, unsubscribe
from flashy.frontend_serve import serve_with_default
from flashy.settings import DEBUG, IN_PRODUCTION
from rest_framework.routers import DefaultRouter
from flashcards.api import *

router = DefaultRouter()
router.register(r'sections', SectionViewSet)
router.register(r'flashcards', FlashcardViewSet)
router.register(r'study', UserFlashcardQuizViewSet)

urlpatterns = [
    url(r'^api/docs/', include('rest_framework_swagger.urls')),
    url(r'^api/me/$', UserDetail.as_view()),
    url(r'^api/register/', register),
    url(r'^api/login/$', login),
    url(r'^api/logout/$', logout),
    url(r'^api/subscribe/$', subscribe),
    url(r'^api/unsubscribe/$', unsubscribe),
    url(r'^api/me/sections/', UserSectionListView.as_view()),
    url(r'^api/resend_confirmation_email/', resend_confirmation_email),
    url(r'^api/verify_email/', verify_email),
    url(r'^api/request_password_reset/', request_password_reset),
    url(r'^api/reset_password/', reset_password),
    url(r'^api/', include(router.urls)),
    url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^api-auth/', include('rest_framework.urls', namespace='rest_framework')),
]

if IN_PRODUCTION:
    urlpatterns += (url(r'^admin/django-ses/', include('django_ses.urls')),)

if DEBUG:
    urlpatterns += [url(r'^app/(?P<path>.*)$', serve_with_default,
                        {'document_root': '../flashy-frontend', 'default_file': 'home.html'})]

